@@ -270,8 +270,11 @@ sub __validator_returns_undef {
         && $self->{schema}->{$schema_key}->{array}){
 
         my $counter = 0;
-        for my $elem (@{$self->{data}->{$key}}){
-            my $return_value = $self->{schema}->{$schema_key}->{validator}->($elem, $self->{data});
+        for my $elem (@{$self->{data}{$key}}){
+            next if !defined $elem
+                && $self->{schema}{$schema_key}{allow_empty};
+
+            my $return_value = $self->{schema}{$schema_key}{validator}($elem, $self->{data});
             if ($return_value){
                 $self->explain("validator error: $return_value (element $counter)\n");
                 $self->error("Execution of validator for '$key' element $counter returns with error: $return_value");
@@ -318,12 +321,15 @@ sub __value_is_valid{
         }
         elsif (ref($self->{schema}->{$key}->{value}) eq 'Regexp'){
             if (ref $self->{data}->{$key} eq ref []
-                && $self->{schema}->{$key}->{array}){
+                && $self->{schema}{$key}{array}){
+
+                for my $elem (@{$self->{data}{$key}}){
+                    next if !defined $elem
+                        && $self->{schema}{$key}{allow_empty};
 
-                for my $elem (@{$self->{data}->{$key}}){
                     $self->explain(">>match '$elem' against '$self->{schema}->{$key}->{value}'");
 
-                    if ($elem =~ m/^$self->{schema}->{$key}->{value}$/){
+                    if ($elem =~ m/^$self->{schema}{$key}{value}$/){
                         $self->explain(" ok.\n");
                     }
                     else{
@@ -359,4 +365,3 @@ sub __value_is_valid{
 }
 
 1;
-
